package action

// Action describes an action to be taken by envy. These are generated by checkers.
type Action struct {
	Path        string
	Priority    int
	AddPath     string
	SetEnv      string
	SetEnvValue string
}

// List is a slice of Action structs with a sort.Interface predefined.
type List []Action

// Implement sort.Interface to sort from shallow path to deep path
func (a List) Len() int      { return len(a) }
func (a List) Swap(i, j int) { a[i], a[j] = a[j], a[i] }
func (a List) Less(i, j int) bool {
	al, bl := len(a[i].Path), len(a[j].Path)
	if al == bl {
		return a[i].Priority < a[j].Priority
	}
	return al < bl
}
